@@ -1,11 +1,11 @@
 // { dg-require-namedlocale "" }
 
-// Copyright (C) 2003, 2005 Free Software Foundation, Inc.
+// Copyright (C) 2003, 2005, 2009 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
 // terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 2, or (at your option)
+// Free Software Foundation; either version 3, or (at your option)
 // any later version.
 
 // This library is distributed in the hope that it will be useful,
@@ -14,9 +14,8 @@
 // GNU General Public License for more details.
 
 // You should have received a copy of the GNU General Public License along
-// with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-// USA.
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
 
 // 27.8.1.4 Overridden virtual functions
 
@@ -24,7 +23,7 @@
 #include <locale>
 #include <testsuite_hooks.h>
 
-void test03()
+void test04()
 {
   using namespace std;
   bool test __attribute__((unused)) = true;
@@ -32,16 +31,18 @@ void test03()
   wfilebuf fb;
   locale loc(locale("en_US.UTF-8"));
   fb.pubimbue(loc);
-  fb.open("tmp_11305-3", ios_base::out);
+  fb.open("tmp_11405-4", ios_base::out);
   wfilebuf::int_type n1 = fb.sputc(0x20000000);
+  wfilebuf::int_type n2 = fb.sputc(0x40000000);
   wfilebuf* f = fb.close();
-	
+  
   VERIFY( n1 != wfilebuf::traits_type::eof() );
+  VERIFY( n2 != wfilebuf::traits_type::eof() );
   VERIFY( f != NULL );
 }
 
 int main()
 {
-  test03();
+  test04();
   return 0;
 }
